
import java.io.*;
import java.util.*;

import static java.util.Arrays.fill;

public class Exp2N {

    final long INF = (long)1e18;

    FastScanner in = new FastScanner(System.in);
    PrintWriter out = new PrintWriter(System.out);

    class Segment implements Comparable<Segment> {
        int left;
        int right;
        long height;

        Segment(int left, int right, long height) {
            this.left = left;
            this.right = right;
            this.height = height;
        }

        @Override
        public int compareTo(Segment other) {
            return Integer.compare(left, other.left);
        }

        @Override
        public String toString() {
            return "Segment: {" + left + ", " + right + ", " + height + "}";
        }

        boolean contains(int point) {
            return left <= point && point <= right;
        }
    }

    long getCover(List<Segment> segments, int point) {
        long sum = 0;
        for (Segment s : segments)
            if (s.contains(point))
                sum += s.height;
        return sum;
    }

    long check(List<Segment> segments, int k) {
        int n = segments.size();
        if (segments.get(0).left > 0)
            return INF;
        int maxR = segments.get(0).right;
        for (int i = 1; i < segments.size(); i++)
            if (segments.get(i).left <= maxR + 1)
                maxR = Math.max(maxR, segments.get(i).right);
        if (maxR < k)
            return INF;
        long ans = 0;
        for (Segment s : segments) {
            ans = Math.max(ans, getCover(segments, s.left));
            ans = Math.max(ans, getCover(segments, s.right));
        }
        return ans;
    }

    public void solve() {
        int n = in.nextInt();
        int k = in.nextInt();
        k--;
        List<Segment> segments = new ArrayList<>();
        for (int i = 0; i < n; i++)
            segments.add(new Segment(in.nextInt() - 1, in.nextInt() - 1, in.nextInt()));
        Collections.sort(segments);
        long res = INF;
        for (int mask = 1; mask < (1 << n); mask++) {
            List<Segment> cur = new ArrayList<>();
            for (int i = 0; i < n; i++)
                if ((mask & (1 << i)) != 0)
                    cur.add(segments.get(i));
            res = Math.min(res, check(cur, k));
        }
        if (res == INF)
            res = -1;
        out.println(res);
    }

    public static void main(String[] args) {
        Exp2N solver = new Exp2N();
        solver.solve();
        solver.out.close();
    }

    public class FastScanner {
        private StringTokenizer tokenizer;
        private BufferedReader reader;

        public FastScanner(InputStream inputStream) {
            reader = new BufferedReader(new InputStreamReader(inputStream));
        }

        public String nextLine() {
            try {
                return reader.readLine();
            } catch (IOException e) {

            }
            return null;
        }

        public String next() {
            while (tokenizer == null || !tokenizer.hasMoreTokens()) {
                String line = null;
                try {
                    line = reader.readLine();
                } catch (IOException e) {
                    // ignore
                }
                if (line == null)
                    return null;
                tokenizer = new StringTokenizer(line);
            }
            return tokenizer.nextToken();
        }

        public int nextInt() {
            return Integer.parseInt(next());
        }

        public long nextLong() {
            return Long.parseLong(next());
        }

        public double nextDouble() {
            return Double.parseDouble(next());
        }

        public void close() {
            try {
                reader.close();
            } catch (IOException e) {
                // ignore
            }
        }
    }
}
