import java.io.*;
import java.util.*;

import static java.util.Arrays.fill;

public class N2logA {

    final int INF = 1_000_000_010;

    FastScanner in = new FastScanner(System.in);
    PrintWriter out = new PrintWriter(System.out);

    class Segment implements Comparable<Segment> {
        int left;
        int right;
        long height;

        Segment(int left, int right, long height) {
            this.left = left;
            this.right = right;
            this.height = height;
        }

        @Override
        public int compareTo(Segment other) {
            return Integer.compare(left, other.left);
        }

        @Override
        public String toString() {
            return "Segment: {" + left + ", " + right + ", " + height + "}";
        }

        boolean contains(int point) {
            return left <= point && point <= right;
        }
    }

    boolean check(List<Segment> segments, long ans, int k) {
        int n = segments.size();
        int[] dp = new int[n];
        Arrays.fill(dp, INF);
        for (int i = 0; i < n; i++)
            if (segments.get(i).contains(0) && segments.get(i).height <= ans)
                dp[i] = -INF;
        for (int i = 1; i < n; i++)
            for (int j = 0; j < i; j++) {
                Segment cur = segments.get(i);
                Segment prev = segments.get(j);
                if (prev.right < cur.right
                        && prev.right >= cur.left
                        && dp[j] < cur.left
                        && cur.height + prev.height <= ans)
                    dp[i] = Math.min(dp[i], prev.right);
                if (dp[j] != INF && prev.right == cur.left - 1 && cur.height <= ans)
                    dp[i] = Math.min(dp[i], cur.left - 1);
            }
        for (int i = 0; i < n; i++)
            if (segments.get(i).contains(k) && dp[i] != INF)
                return true;
        return false;
    }

    public void solve() {
        int n = in.nextInt();
        int k = in.nextInt();
        k--;
        List<Segment> segments = new ArrayList<>();
        for (int i = 0; i < n; i++)
            segments.add(new Segment(in.nextInt() - 1, in.nextInt() - 1, in.nextInt()));
        Collections.sort(segments);
        long low = 0;
        long high = 2 * INF;
        while (high - low > 1) {
            long mid = (low + high) / 2;
            if (check(segments, mid, k))
                high = mid;
            else
                low = mid;
        }
        if (high == 2 * INF)
            high = -1;
        out.println(high);
    }

    public static void main(String[] args) {
        N2logA solver = new N2logA();
        solver.solve();
        solver.out.close();
    }

    public class FastScanner {
        private StringTokenizer tokenizer;
        private BufferedReader reader;

        public FastScanner(InputStream inputStream) {
            reader = new BufferedReader(new InputStreamReader(inputStream));
        }

        public String nextLine() {
            try {
                return reader.readLine();
            } catch (IOException e) {

            }
            return null;
        }

        public String next() {
            while (tokenizer == null || !tokenizer.hasMoreTokens()) {
                String line = null;
                try {
                    line = reader.readLine();
                } catch (IOException e) {
                    // ignore
                }
                if (line == null)
                    return null;
                tokenizer = new StringTokenizer(line);
            }
            return tokenizer.nextToken();
        }

        public int nextInt() {
            return Integer.parseInt(next());
        }

        public long nextLong() {
            return Long.parseLong(next());
        }

        public double nextDouble() {
            return Double.parseDouble(next());
        }

        public void close() {
            try {
                reader.close();
            } catch (IOException e) {
                // ignore
            }
        }
    }
}
