import java.io.*;
import java.util.*;

public class ThicknessOne {

    FastScanner in = new FastScanner(System.in);
    PrintWriter out = new PrintWriter(System.out);

    class Segment implements Comparable<Segment> {
        int left;
        int right;
        long height;

        Segment(int left, int right, long height) {
            this.left = left;
            this.right = right;
            this.height = height;
        }

        @Override
        public int compareTo(Segment other) {
            return Integer.compare(left, other.left);
        }

        @Override
        public String toString() {
            return "Segment: {" + left + ", " + right + ", " + height + "}";
        }

        boolean contains(int point) {
            return left <= point && point <= right;
        }
    }

    boolean canCover(List<Segment> segments, int k) {
        int maxR = 0;
        boolean any = false;
        for (Segment s : segments)
            if (s.contains(0)) {
                any = true;
                maxR = Math.max(maxR, s.right);
            }
        if (!any)
            return false;
        for (Segment s : segments)
            if (s.left <= maxR + 1)
                maxR = Math.max(maxR, s.right);
        return maxR >= k;
    }
    
    boolean canCoverWithoutOverlaps(List<Segment> segments, int k) {
        Set<Integer> rightEnds = new HashSet<>();
        for (Segment s : segments)
            if (s.contains(0)) 
                rightEnds.add(s.right);
        if (rightEnds.isEmpty())
            return false;
        for (Segment s : segments) 
            if (rightEnds.contains(s.left - 1))
                rightEnds.add(s.right);
        return Collections.max(rightEnds) >= k;
    }

    public void solve() {
        int n = in.nextInt();
        int k = in.nextInt();
        k--;
        List<Segment> segments = new ArrayList<>();
        for (int i = 0; i < n; i++)
            segments.add(new Segment(in.nextInt() - 1, in.nextInt() - 1, in.nextInt()));
        Collections.sort(segments);
        if (canCoverWithoutOverlaps(segments, k)) 
            out.println(1);
        else
            out.println(canCover(segments, k) ? 2 : -1);
    }

    public static void main(String[] args) {
        ThicknessOne solver = new ThicknessOne();
        solver.solve();
        solver.out.close();
    }

    public class FastScanner {
        private StringTokenizer tokenizer;
        private BufferedReader reader;

        public FastScanner(InputStream inputStream) {
            reader = new BufferedReader(new InputStreamReader(inputStream));
        }

        public String nextLine() {
            try {
                return reader.readLine();
            } catch (IOException e) {

            }
            return null;
        }

        public String next() {
            while (tokenizer == null || !tokenizer.hasMoreTokens()) {
                String line = null;
                try {
                    line = reader.readLine();
                } catch (IOException e) {
                    // ignore
                }
                if (line == null)
                    return null;
                tokenizer = new StringTokenizer(line);
            }
            return tokenizer.nextToken();
        }

        public int nextInt() {
            return Integer.parseInt(next());
        }

        public long nextLong() {
            return Long.parseLong(next());
        }

        public double nextDouble() {
            return Double.parseDouble(next());
        }

        public void close() {
            try {
                reader.close();
            } catch (IOException e) {
                // ignore
            }
        }
    }
}
