import java.io.*;
import java.util.*;

public class ThicknessOneN2 {
    FastScanner in = new FastScanner(System.in);
    PrintWriter out = new PrintWriter(System.out);

    class Segment implements Comparable<Segment> {
        int left;
        int right;
        long height;

        Segment(int left, int right, long height) {
            this.left = left;
            this.right = right;
            this.height = height;
        }

        @Override
        public int compareTo(Segment other) {
            return Integer.compare(left, other.left);
        }

        @Override
        public String toString() {
            return "Segment: {" + left + ", " + right + ", " + height + "}";
        }

        boolean contains(int point) {
            return left <= point && point <= right;
        }

        boolean intersects(Segment other) {
            return Math.max(left, other.left) <= Math.min(right, other.right);
        }
    }

    boolean[][] graph;
    boolean[] was;

    void dfs(int v) {
        was[v] = true;
        for (int to = 0; to < graph.length; to++)
            if (graph[v][to] && !was[to])
                dfs(to);
    }

    boolean canCover(List<Segment> segments, int k) {
        int n = segments.size();
        graph = new boolean[n + 2][n + 2];
        was = new boolean[n + 2];
        for (int i = 0; i < n; i++) {
            if (segments.get(i).contains(0)) {
                graph[0][i + 2] = graph[i + 2][0] = true;
            }
            if (segments.get(i).contains(k)) {
                graph[1][i + 2] = graph[i + 2][1] = true;
            }
            for (int j = i + 1; j < n; j++)
                if (segments.get(i).intersects(segments.get(j)) || segments.get(i).right + 1 == segments.get(j).left)
                    graph[i + 2][j + 2] = graph[j + 2][i + 2] = true;
        }
        dfs(0);
        return was[1];
    }

    boolean canCoverWithoutOverlaps(List<Segment> segments, int k) {
        Set<Integer> rightEnds = new HashSet<>();
        for (Segment s : segments)
            if (s.contains(0))
                rightEnds.add(s.right);
        if (rightEnds.isEmpty())
            return false;
        for (Segment s : segments)
            if (rightEnds.contains(s.left - 1))
                rightEnds.add(s.right);
        return Collections.max(rightEnds) >= k;
    }

    public void solve() {
        int n = in.nextInt();
        int k = in.nextInt() - 1;
        List<Segment> segments = new ArrayList<>();
        for (int i = 0; i < n; i++)
            segments.add(new Segment(in.nextInt() - 1, in.nextInt() - 1, in.nextInt()));
        Collections.sort(segments);
        if (canCoverWithoutOverlaps(segments, k))
            out.println(1);
        else
            out.println(canCover(segments, k) ? 2 : -1);
    }

    public static void main(String[] args) {
        ThicknessOneN2 solver = new ThicknessOneN2();
        solver.solve();
        solver.out.close();
    }

    public class FastScanner {
        private StringTokenizer tokenizer;
        private BufferedReader reader;

        public FastScanner(InputStream inputStream) {
            reader = new BufferedReader(new InputStreamReader(inputStream));
        }

        public String nextLine() {
            try {
                return reader.readLine();
            } catch (IOException e) {

            }
            return null;
        }

        public String next() {
            while (tokenizer == null || !tokenizer.hasMoreTokens()) {
                String line = null;
                try {
                    line = reader.readLine();
                } catch (IOException e) {
                    // ignore
                }
                if (line == null)
                    return null;
                tokenizer = new StringTokenizer(line);
            }
            return tokenizer.nextToken();
        }

        public int nextInt() {
            return Integer.parseInt(next());
        }

        public long nextLong() {
            return Long.parseLong(next());
        }

        public double nextDouble() {
            return Double.parseDouble(next());
        }

        public void close() {
            try {
                reader.close();
            } catch (IOException e) {
                // ignore
            }
        }
    }
}
