#include <cstdio>
#include <functional>
#include <set>
#include <algorithm>
#include <vector>
using namespace std;

const int N = 200500;

struct seg {
    int l, r, w, d;
    seg() = default;
} S[N];

vector<seg*> byL;

const int inf = 2 * 1000 * 1000 * 1000 + 42;

struct OpenSegments {
    set<seg*> open;
    OpenSegments() = default;
    pair<int, seg*> getMinR(int crit, int mxw) {
        pair<int, seg*> ans(inf, nullptr);
        for (auto* s : open) {
            if (s->w <= mxw || s->r == crit)
                ans = min(ans, make_pair(s->r, s));
        }
        return ans;
    }
    void add(seg* s) {
        open.insert(s);
    }
    void del(seg* s) {
        open.erase(s);
    }
    void clear() {
        open.clear();
    }
} open;

struct Event {
    int t;
    int tp;
    seg* s;
    friend bool operator <(const Event& a, const Event& b) {
        if (a.t != b.t)
            return a.t < b.t;
        if (a.tp != b.tp)
            return a.tp < b.tp;
        return a.s < b.s;
    }
};

int n, k;

bool can(int lim) {
    open.clear();
    set<Event> ev;
    for (int i = 0; i < n; i++) {
        if (S[i].w <= lim) {
            ev.insert(Event {S[i].l, 0, &S[i]});
        }
    }
    while (!ev.empty()) {
        auto e = *ev.begin();
        ev.erase(ev.begin());
        if (e.tp == 0) {
            auto* s = e.s;
            s->d = inf;
            if (s->l == 1) {
                s->d = 0;
            } else {
                auto pr = open.getMinR(s->l - 1, lim - s->w);
                if (pr.second != nullptr && pr.second->r < s->r) {
                    s->d = pr.first;
                }
            }
            if (s->d != inf) {
                ev.insert(Event {s->d, 1, s});
                ev.insert(Event {s->r + 1, 2, s});
                if (s->r == k) {
                    return true;
                }
            }
        } else if (e.tp == 1) {
            open.add(e.s);
        } else {
            open.del(e.s);
        }
    }
    return false;
}

int main() {
    scanf("%d %d", &n, &k);
    for (int i = 0; i < n; i++) {
        int l, r, w;
        scanf("%d %d %d", &l, &r, &w);
        l = max(l, 1);
        r = min(r, k);
        S[i] = {l, r, w, -1};
    }

    int lo = 0, hi = inf;
    while (hi - lo > 1) {
        int lim = lo + (hi - lo) / 2;
        if (can(lim)) {
            hi = lim;
        } else {
            lo = lim;
        }
    }
    int ans = hi;
    printf("%d", ans == inf ? -1 : ans);
}
