#include <cstdio>
#include <functional>
#include <set>
#include <map>
#include <algorithm>
#include <vector>
using namespace std;

const int N = 200500;

struct seg {
    int l, r, w, d, p;
    seg() = default;
} S[N];

const int inf = 2 * 1000 * 1000 * 1000;

struct SegTree {
    vector<pair<int, seg*>> ws;
    int N = 0;
    vector<int> T;
    void add(int w, seg* s) {
        ws.emplace_back(w, s);
    }
    void clear() {
        T.assign(2 * N, inf);
    }
    void init() {
        sort(ws.begin(), ws.end());
        for (int i = 0; i < (int)ws.size(); i++)
            ws[i].second->p = i;
        N = 1;
        while (N < (int)ws.size())
            N <<= 1;
        clear();
    }
    int get(int l, int r) {
        l += N;
        r += N;
        int ans = inf;
        while (l <= r) {
            ans = min({ans, T[l], T[r]});
            l = (l + 1) >> 1;
            r = (r - 1) >> 1;
        }
        return ans;
    }
    int get_pref(int w) {
        auto it = upper_bound(ws.begin(), ws.end(), make_pair(w, S + N));
        return get(0, it - ws.begin() - 1);
    }
    void upd(int i, int val) {
        i += N;
        T[i] = val;
        while ((i >>= 1) > 0) {
            T[i] = min(T[2 * i], T[2 * i + 1]);
        }
    }
};

struct OpenSegments {
    SegTree ST;
    map<int, int> cnt;
    OpenSegments() = default;
    int getMinR(int crit, int mxw) {
        auto it = cnt.find(crit);
        if (it != cnt.end() && it->second > 0) {
            return crit;
        }
        return ST.get_pref(mxw);
    }
    void add(seg* s) {
        cnt[s->r]++;
        ST.upd(s->p, s->r);
    }
    void del(seg* s) {
        cnt[s->r]--;
        ST.upd(s->p, inf);
    }
    void clear() {
        cnt.clear();
        ST.clear();
    }
} open;

struct Event {
    int t;
    int tp;
    seg* s;
    friend bool operator <(const Event& a, const Event& b) {
        if (a.t != b.t)
            return a.t < b.t;
        if (a.tp != b.tp)
            return a.tp < b.tp;
        return a.s < b.s;
    }
};

int n, k;

bool can(int lim) {
    open.clear();
    set<Event> ev;
    for (int i = 0; i < n; i++) {
        if (S[i].w <= lim) {
            ev.insert(Event {S[i].l, 0, &S[i]});
        }
    }
    while (!ev.empty()) {
        auto e = *ev.begin();
        ev.erase(ev.begin());
        if (e.tp == 0) {
            auto* s = e.s;
            s->d = inf;
            if (s->l == 1) {
                s->d = 0;
            } else {
                int mnr = open.getMinR(s->l - 1, lim - s->w);
                if (mnr < s->r) {
                    s->d = mnr;
                }
            }
            if (s->d != inf) {
                ev.insert(Event {s->d, 1, s});
                ev.insert(Event {s->r + 1, 2, s});
                if (s->r == k) {
                    return true;
                }
            }
        } else if (e.tp == 1) {
            open.add(e.s);
        } else {
            open.del(e.s);
        }
    }
    return false;
}

int main() {
    scanf("%d %d", &n, &k);
    for (int i = 0; i < n; i++) {
        int l, r, w;
        scanf("%d %d %d", &l, &r, &w);
        l = max(l, 1);
        r = min(r, k);
        S[i] = {l, r, w, -1, -1};
        open.ST.add(w, &S[i]);
    }
    open.ST.init();

    int lo = 0, hi = inf;
    while (hi - lo > 1) {
        int lim = lo + (hi - lo) / 2;
        if (can(lim)) {
            hi = lim;
        } else {
            lo = lim;
        }
    }
    int ans = hi;
    printf("%d", ans == inf ? -1 : ans);
}
